"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAttachment = exports.deleteAttachment = exports.listAttachments = exports.generateAttachmentUploadUrl = exports.WebhookIdentityType = exports.DemoContactType = exports.CrmAttachmentAttachmentType = exports.AttachmentType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixContactsV4Attachment = __importStar(require("./contacts-v4-attachment-attachments.http.js"));
const image_1 = require("@wix/sdk-runtime/transformations/image");
const document_1 = require("@wix/sdk-runtime/transformations/document");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
var AttachmentType;
(function (AttachmentType) {
    /** Unknown attachment type. */
    AttachmentType["UNKNOWN"] = "UNKNOWN";
    /** Attachment is an image file. */
    AttachmentType["IMAGE"] = "IMAGE";
    /** Attachment is a document or any non-image file type. */
    AttachmentType["OTHER"] = "OTHER";
})(AttachmentType || (exports.AttachmentType = AttachmentType = {}));
var CrmAttachmentAttachmentType;
(function (CrmAttachmentAttachmentType) {
    CrmAttachmentAttachmentType["UNKNOWN"] = "UNKNOWN";
    CrmAttachmentAttachmentType["DOCUMENT"] = "DOCUMENT";
    CrmAttachmentAttachmentType["IMAGE"] = "IMAGE";
})(CrmAttachmentAttachmentType || (exports.CrmAttachmentAttachmentType = CrmAttachmentAttachmentType = {}));
var DemoContactType;
(function (DemoContactType) {
    DemoContactType["KAT"] = "KAT";
    DemoContactType["DAN"] = "DAN";
})(DemoContactType || (exports.DemoContactType = DemoContactType = {}));
var WebhookIdentityType;
(function (WebhookIdentityType) {
    WebhookIdentityType["UNKNOWN"] = "UNKNOWN";
    WebhookIdentityType["ANONYMOUS_VISITOR"] = "ANONYMOUS_VISITOR";
    WebhookIdentityType["MEMBER"] = "MEMBER";
    WebhookIdentityType["WIX_USER"] = "WIX_USER";
    WebhookIdentityType["APP"] = "APP";
})(WebhookIdentityType || (exports.WebhookIdentityType = WebhookIdentityType = {}));
/**
 * Generates an upload URL for uploading a file as an attachment to a specified contact.
 *
 * To learn how to use the generated upload URL in the response to upload an attachment file,
 * see the Upload API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/media/files/upload-api) | [REST](https://dev.wix.com/docs/rest/assets/media/media-manager/files/upload-api)).
 * @param contactId - ID of the contact for whom the attachment is being uploaded.
 * @param fileName - File name of the attachment including the extension, for example, `contact-cv.pdf`.
 * @public
 * @requiredField contactId
 * @requiredField fileName
 * @requiredField options
 * @requiredField options.mimeType
 * @permissionId CONTACTS_ATTACHMENTS.MODIFY
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GenerateAttachmentUploadUrl
 */
async function generateAttachmentUploadUrl(contactId, fileName, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        contactId: contactId,
        fileName: fileName,
        mimeType: options?.mimeType,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.generateAttachmentUploadUrl(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                contactId: '$[0]',
                fileName: '$[1]',
                mimeType: '$[2].mimeType',
            },
            singleArgumentUnchanged: false,
        }, ['contactId', 'fileName', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.generateAttachmentUploadUrl = generateAttachmentUploadUrl;
/**
 * Retrieves a list of attachments associated with a specified contact.
 * @param contactId - Contact ID for the attachments to be listed.
 * @public
 * @requiredField contactId
 * @permissionId CONTACTS_ATTACHMENTS.VIEW
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.ListAttachments
 */
async function listAttachments(contactId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        contactId: contactId,
        paging: options?.paging,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.listAttachments(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(result.data, [
            {
                transformFn: image_1.transformRESTImageToSDKImage,
                paths: [
                    { path: 'attachments.image' },
                    { path: 'attachments.previewImage' },
                ],
            },
            {
                transformFn: document_1.transformRESTDocumentToSDKDocument,
                paths: [{ path: 'attachments.document' }],
            },
        ]));
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { contactId: '$[0]', paging: '$[1].paging' },
            singleArgumentUnchanged: false,
        }, ['contactId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listAttachments = listAttachments;
/**
 * Deletes the specified attachment from the specified contact.
 * @public
 * @requiredField identifiers
 * @requiredField identifiers.attachmentId
 * @requiredField identifiers.contactId
 * @permissionId CONTACTS_ATTACHMENTS.MODIFY
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.DeleteAttachment
 */
async function deleteAttachment(identifiers) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        contactId: identifiers?.contactId,
        attachmentId: identifiers?.attachmentId,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.deleteAttachment(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                contactId: '$[0].contactId',
                attachmentId: '$[0].attachmentId',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deleteAttachment = deleteAttachment;
/**
 * Retrieves the specified attachment for the specified contact.
 * @public
 * @requiredField identifiers
 * @requiredField identifiers.attachmentId
 * @requiredField identifiers.contactId
 * @permissionId CONTACTS_ATTACHMENTS.VIEW
 * @permissionScope Manage Stores
 * @permissionScopeId SCOPE.STORES.MANAGE-STORES
 * @permissionScope Manage Events
 * @permissionScopeId SCOPE.EVENTS.MANAGE-EVENTS
 * @permissionScope Manage Contact Attachments
 * @permissionScopeId SCOPE.DC-CONTACTS.MANAGE-CONTACT-ATTACHMENTS
 * @applicableIdentity APP
 * @returns The requested attachment.
 * @fqn com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GetAttachment
 */
async function getAttachment(identifiers) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        contactId: identifiers?.contactId,
        attachmentId: identifiers?.attachmentId,
    });
    const reqOpts = ambassadorWixContactsV4Attachment.getAttachment(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)((0, transform_paths_1.transformPaths)(result.data, [
            {
                transformFn: image_1.transformRESTImageToSDKImage,
                paths: [
                    { path: 'attachment.image' },
                    { path: 'attachment.previewImage' },
                ],
            },
            {
                transformFn: document_1.transformRESTDocumentToSDKDocument,
                paths: [{ path: 'attachment.document' }],
            },
        ]))?.attachment;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                contactId: '$[0].contactId',
                attachmentId: '$[0].attachmentId',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getAttachment = getAttachment;
//# sourceMappingURL=contacts-v4-attachment-attachments.universal.js.map