import { renameKeysFromRESTResponseToSDKResponse } from '@wix/sdk-runtime/rename-all-nested-keys';
import { transformRESTDocumentToSDKDocument } from '@wix/sdk-runtime/transformations/document';
import { transformRESTImageToSDKImage } from '@wix/sdk-runtime/transformations/image';
import { transformRESTTimestampToSDKTimestamp } from '@wix/sdk-runtime/transformations/timestamp';
import { transformPaths } from '@wix/sdk-runtime/transformations/transform-paths';
import { EventDefinition } from '@wix/sdk-types';
import { deleteAttachment as universalDeleteAttachment, generateAttachmentUploadUrl as universalGenerateAttachmentUploadUrl, getAttachment as universalGetAttachment, listAttachments as universalListAttachments, } from './contacts-v4-attachment-attachments.universal.js';
export const __metadata = { PACKAGE_NAME: '@wix/crm' };
export function generateAttachmentUploadUrl(httpClient) {
    return (contactId, fileName, options) => universalGenerateAttachmentUploadUrl(contactId, fileName, options, 
    // @ts-ignore
    { httpClient });
}
export function listAttachments(httpClient) {
    return (contactId, options) => universalListAttachments(contactId, options, 
    // @ts-ignore
    { httpClient });
}
export function deleteAttachment(httpClient) {
    return (identifiers) => universalDeleteAttachment(identifiers, 
    // @ts-ignore
    { httpClient });
}
export function getAttachment(httpClient) {
    return (identifiers) => universalGetAttachment(identifiers, 
    // @ts-ignore
    { httpClient });
}
export const onAttachmentCreated = EventDefinition('wix.contacts.v4.attachment_created', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [{ path: 'entity.image' }, { path: 'entity.previewImage' }],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [{ path: 'entity.document' }],
    },
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export const onAttachmentDeleted = EventDefinition('wix.contacts.v4.attachment_deleted', true, (event) => renameKeysFromRESTResponseToSDKResponse(transformPaths(event, [
    {
        transformFn: transformRESTImageToSDKImage,
        paths: [
            { path: 'undefined.image' },
            { path: 'undefined.previewImage' },
        ],
    },
    {
        transformFn: transformRESTDocumentToSDKDocument,
        paths: [{ path: 'undefined.document' }],
    },
    {
        transformFn: transformRESTTimestampToSDKTimestamp,
        paths: [{ path: 'metadata.eventTime' }],
    },
])))();
export { AttachmentType, CrmAttachmentAttachmentType, DemoContactType, WebhookIdentityType, } from './contacts-v4-attachment-attachments.universal.js';
//# sourceMappingURL=contacts-v4-attachment-attachments.public.js.map