"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getAttachment = exports.deleteAttachment = exports.listAttachments = exports.generateAttachmentUploadUrl = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url(opts) {
    const domainToMappings = {
        'api._api_base_domain_': [
            {
                srcPath: '/contacts-attachments-app',
                destPath: '',
            },
        ],
        'www._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/attachments',
                destPath: '/v4/attachments',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/attachments',
                destPath: '/v4/attachments',
            },
        ],
        'editor._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/attachments',
                destPath: '/v4/attachments',
            },
        ],
        'blocks._base_domain_': [
            {
                srcPath: '/_api/contacts/v4/attachments',
                destPath: '/v4/attachments',
            },
        ],
        'create.editorx': [
            {
                srcPath: '/_api/contacts/v4/attachments',
                destPath: '/v4/attachments',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/contacts/v4/attachments',
                destPath: '/v4/attachments',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_crm_attachments';
/**
 * Generates an upload URL for uploading a file as an attachment to a specified contact.
 *
 * To learn how to use the generated upload URL in the response to upload an attachment file,
 * see the Upload API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/media/files/upload-api) | [REST](https://dev.wix.com/docs/rest/assets/media/media-manager/files/upload-api)).
 */
function generateAttachmentUploadUrl(payload) {
    function __generateAttachmentUploadUrl({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.attachment',
            method: 'POST',
            methodFqn: 'com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GenerateAttachmentUploadUrl',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url({
                protoPath: '/v4/attachments/{contactId}/upload-url',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __generateAttachmentUploadUrl;
}
exports.generateAttachmentUploadUrl = generateAttachmentUploadUrl;
/** Retrieves a list of attachments associated with a specified contact. */
function listAttachments(payload) {
    function __listAttachments({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.attachment',
            method: 'GET',
            methodFqn: 'com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.ListAttachments',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url({ protoPath: '/v4/attachments/{contactId}', data: payload, host }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'attachments.image.urlExpirationDate' },
                        { path: 'attachments.document.urlExpirationDate' },
                        { path: 'attachments.previewImage.urlExpirationDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __listAttachments;
}
exports.listAttachments = listAttachments;
/** Deletes the specified attachment from the specified contact. */
function deleteAttachment(payload) {
    function __deleteAttachment({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.attachment',
            method: 'DELETE',
            methodFqn: 'com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.DeleteAttachment',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url({
                protoPath: '/v4/attachments/{contactId}/{attachmentId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deleteAttachment;
}
exports.deleteAttachment = deleteAttachment;
/** Retrieves the specified attachment for the specified contact. */
function getAttachment(payload) {
    function __getAttachment({ host }) {
        const metadata = {
            entityFqdn: 'wix.contacts.v4.attachment',
            method: 'GET',
            methodFqn: 'com.wixpress.contacts.attachments.v4.ContactAttachmentsServiceV4.GetAttachment',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressContactsAttachmentsV4ContactAttachmentsServiceV4Url({
                protoPath: '/v4/attachments/{contactId}/{attachmentId}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'attachment.image.urlExpirationDate' },
                        { path: 'attachment.document.urlExpirationDate' },
                        { path: 'attachment.previewImage.urlExpirationDate' },
                    ],
                },
            ]),
        };
        return metadata;
    }
    return __getAttachment;
}
exports.getAttachment = getAttachment;
//# sourceMappingURL=contacts-v4-attachment-attachments.http.js.map