import { EventDefinition, HttpClient } from '@wix/sdk-types';
import { AttachmentCreatedEnvelope, AttachmentDeletedEnvelope, ContactAttachment, DeleteAttachmentIdentifiers, GenerateAttachmentUploadUrlOptions, GenerateAttachmentUploadUrlResponse, GetAttachmentIdentifiers, ListAttachmentsOptions, ListAttachmentsResponse } from './contacts-v4-attachment-attachments.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function generateAttachmentUploadUrl(httpClient: HttpClient): GenerateAttachmentUploadUrlSignature;
interface GenerateAttachmentUploadUrlSignature {
    /**
     * Generates an upload URL for uploading a file as an attachment to a specified contact.
     *
     * To learn how to use the generated upload URL in the response to upload an attachment file,
     * see the Upload API ([SDK](https://dev.wix.com/docs/sdk/backend-modules/media/files/upload-api) | [REST](https://dev.wix.com/docs/rest/assets/media/media-manager/files/upload-api)).
     * @param - ID of the contact for whom the attachment is being uploaded.
     * @param - File name of the attachment including the extension, for example, `contact-cv.pdf`.
     */
    (contactId: string, fileName: string, options: GenerateAttachmentUploadUrlOptions): Promise<GenerateAttachmentUploadUrlResponse>;
}
export declare function listAttachments(httpClient: HttpClient): ListAttachmentsSignature;
interface ListAttachmentsSignature {
    /**
     * Retrieves a list of attachments associated with a specified contact.
     * @param - Contact ID for the attachments to be listed.
     */
    (contactId: string, options?: ListAttachmentsOptions | undefined): Promise<ListAttachmentsResponse>;
}
export declare function deleteAttachment(httpClient: HttpClient): DeleteAttachmentSignature;
interface DeleteAttachmentSignature {
    /**
     * Deletes the specified attachment from the specified contact.
     */
    (identifiers: DeleteAttachmentIdentifiers): Promise<void>;
}
export declare function getAttachment(httpClient: HttpClient): GetAttachmentSignature;
interface GetAttachmentSignature {
    /**
     * Retrieves the specified attachment for the specified contact.
     * @returns The requested attachment.
     */
    (identifiers: GetAttachmentIdentifiers): Promise<ContactAttachment>;
}
export declare const onAttachmentCreated: EventDefinition<AttachmentCreatedEnvelope, "wix.contacts.v4.attachment_created">;
export declare const onAttachmentDeleted: EventDefinition<AttachmentDeletedEnvelope, "wix.contacts.v4.attachment_deleted">;
export { ActionEvent, AttachmentCreatedEnvelope, AttachmentDeletedEnvelope, AttachmentMedia, AttachmentMediaMediaOneOf, AttachmentMetadata, AttachmentSource, AttachmentType, BaseEventMetadata, ContactAttachment, ContactAttachmentMediaOneOf, CreateDemoAttachmentRequest, CreateDemoAttachmentResponse, CrmAttachment, CrmAttachmentAttachmentType, CrmAttachmentUploadedEvent, DeleteAttachmentIdentifiers, DeleteAttachmentRequest, DeleteAttachmentResponse, DemoContactType, DomainEvent, DomainEventBodyOneOf, Empty, EntityCreatedEvent, EntityDeletedEvent, EntityUpdatedEvent, EventMetadata, GenerateAttachmentUploadUrlOptions, GenerateAttachmentUploadUrlRequest, GenerateAttachmentUploadUrlResponse, GetAttachmentIdentifiers, GetAttachmentRequest, GetAttachmentResponse, IdentificationData, IdentificationDataIdOneOf, ListAttachmentsOptions, ListAttachmentsRequest, ListAttachmentsResponse, MessageEnvelope, Paging, PagingMetadata, RestoreInfo, WebhookIdentityType, } from './contacts-v4-attachment-attachments.universal.js';
